@@ -1,6 +1,6 @@
 /*
 This file is part of libspnav, part of the spacenav project (spacenav.sf.net)
-Copyright (C) 2007-2022 John Tsiombikas <nuclear@member.fsf.org>
+Copyright (C) 2007-2023 John Tsiombikas <nuclear@member.fsf.org>
 
 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions are met:
@@ -298,6 +298,7 @@ static int x11_sensitivity(double sens)
 
 int spnav_sensitivity(double sens)
 {
+	float fval;
 	struct reqresp rr;
 
 #ifdef SPNAV_USE_X11
@@ -306,10 +307,11 @@ int spnav_sensitivity(double sens)
 	}
 #endif
 
+	fval = sens;
+
 	if(proto == 0) {
 		if(sock) {
 			ssize_t bytes;
-			float fval = sens;
 
 			while((bytes = write(sock, &fval, sizeof fval)) <= 0 && errno == EINTR);
 			if(bytes <= 0) {
@@ -320,7 +322,7 @@ int spnav_sensitivity(double sens)
 		return -1;
 	}
 
-	rr.data[0] = *(int*)&sens;
+	rr.data[0] = *(int*)&fval;
 	if(request(REQ_SET_SENS, &rr, TIMEOUT) == -1) {
 		return -1;
 	}
@@ -1092,3 +1094,23 @@ int spnav_cfg_get_serial(char *buf, int bufsz)
 {
 	return request_str(REQ_GCFG_SERDEV, buf, bufsz, TIMEOUT);
 }
+
+int spnav_cfg_set_repeat(int msec)
+{
+	struct reqresp rr = {0};
+
+	if(msec < 0) msec = -1;
+
+	rr.data[0] = msec;
+	return request(REQ_SCFG_REPEAT, &rr, TIMEOUT);
+}
+
+int spnav_cfg_get_repeat(void)
+{
+	struct reqresp rr = {0};
+
+	if(request(REQ_GCFG_REPEAT, &rr, TIMEOUT) == -1) {
+		return -1;
+	}
+	return rr.data[0];
+}
